MIN_LENGTH = 1
MAX_LENGTH = 400

IDENTIFIER_REGEX_CONDITION = r"^[A-Za-z0-9\.\-:_,=\/@]+$"
MSMQ_NAME_REGEX_CONDITION = r"^[A-Za-z0-9_\.]+$"


ORG = "ORG"
APPLICATION = "APP"
PROJECT = "PRJ"
TYPE = "TYPE"
NAMESPACE = "NS"

# SERVICE_CONFIG_ID
SERVICE_CONFIG_ID_REMIND = "remind"
SERVICE_CONFIG_ID_UTILS = "utils"
SERVICE_CONFIG_ID_SSO_FE = "sso_fe"
SERVICE_CONFIG_ID_SSO_API = "sso_api"
SERVICE_CONFIG_ID_GATEWAY = "gateway"
SERVICE_CONFIG_ID_CERTS = "certs"
SERVICE_CONFIG_ID_PERMS = "perms"

# COMMON ACTIONS
COMMON_ACTION_OUTPOST_CLEAR = "CLEAR_OUTPOST"
REMIND_ACTION_CREATE = "CREATE_REMINDER"
REMIND_ACTION_DELETE = "DELETE_REMINDER"
REMIND_ACTION_IN_MINS = 3
