{% load static %}
<!DOCTYPE html>
<html lang="en">
  <head>
    <meta charset="UTF-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <meta http-equiv="X-UA-Compatible" content="ie=edge" />
    <title>{% block page_title %}{% endblock %}</title>
    <link rel="preconnect" href="https://fonts.googleapis.com" />
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin />
    <link
      href="https://fonts.googleapis.com/css?family=Comfortaa|Open+Sans:300,400,400i,600,600i,700"
      rel="stylesheet"
    />
    <link
      href="https://fonts.googleapis.com/css?family=Poppins:400,500,600,700"
      rel="stylesheet"
    />
    <script src="{% static 'js/jquery/3.6.0/jquery.min.js' %}"></script>
    <script src="{% static 'js/bootstrap/5.1.3/bootstrap.min.js' %}"></script>
    <script src="{% static 'js/adminlte/3.2.0/adminlte.min.js' %}"></script>
    <script src="{% static 'js/toastr/0.0.1/toastr.min.js' %}"></script>
    <script
      src="https://kit.fontawesome.com/036aa91418.js"
      crossorigin="anonymous"
    ></script>

    <script
      src="https://cdn.jsdelivr.net/npm/bootstrap@4.5.3/dist/js/bootstrap.bundle.min.js"
      integrity="sha384-ho+j7jyWK8fNQe+A12Hb8AhRq26LrZ/JpcUGGOn+Y7RsweNrtN/tE3MoK7ZeZDyx"
      crossorigin="anonymous"
    ></script>

    <link
      rel="stylesheet"
      href="{% static 'css/adminlte/3.2.0/adminlte.min.css' %}"
    />
    <link
      rel="stylesheet"
      href="{% static 'css/toastr/0.0.1/toastr.min.css' %}"
    />
    <link
      rel="stylesheet"
      href="{% static 'css/kubefacets/0.0.1/global.css' %}"
    />
    <script>
      toastr.options = {
        "closeButton": true,
      }
    </script>
    {% block css_files %}{% endblock %} {% block js_files %}{% endblock %}
  </head>
  <body class="layout-top-nav">
    <div>
      <div class="content-wrapper mt-0 login-page">
        <div>{% block content %}{% endblock %}</div>
        <div class="mb-2"></div>
      </div>

      <footer class="main-footer">
        <div class="text-center">
          <strong>
            Copyright &copy; 2023
            <a href="https://kubefacets.com">kubefacets.com</a>.
          </strong>
          All rights reserved.
        </div>
      </footer>
    </div>
  </body>
  {% if messages %} {% for message in messages %}
  <script>
    toastr.{{ message.tags }}('{{ message|escapejs }}');
  </script>
  {% endfor %} {% endif %}
</html>
